@@ -9,7 +9,7 @@ import argparse
 import inspect
 from enum import Enum
 from types import SimpleNamespace
-from typing import Callable, Dict, Any
+from typing import Callable, Dict, Any, List
 
 import json
 import yaml
@@ -18,15 +18,15 @@ class StringEnum(Enum):
     def __str__(self):
         return str(self.value)
 
-def yml2config(config_file_path: str) -> SimpleNamespace:
+def file2namespace(config_file_path: str) -> SimpleNamespace:
     """
-    Loads a `YAML` file containing representing configuration and parses
+    Loads a `YAML` or `JSON` file containing representing configuration and parses
     it as a `SimpleNamespace` object.
 
     Parameters
     ----------
     config_file_path : str
-        Path where the `YAML` file is located.
+        Path where the `YAML` or `JSON` file is located.
 
     Returns
     -------
@@ -59,7 +59,7 @@ def yml2config(config_file_path: str) -> SimpleNamespace:
                 the following error happened: {err}"
         raise argparse.ArgumentTypeError(msg)
 
-def get_args_from_signature(method: Callable) -> argparse.Namespace:
+def get_parser_from_signature(method: Callable, extra_arguments: List[str] = []) -> argparse.ArgumentParser:
     """
     Automatically parses all the arguments to match an specific method. The method should
     implement type hinting in order for this to work. All arguments required by the method
@@ -75,39 +75,73 @@ def get_args_from_signature(method: Callable) -> argparse.Namespace:
 
     Returns
     -------
-    argparse.Namespace
-        The arguments parsed. You can call `method` with `**vars(...)` then.
+    argparse.ArgumentParser
+        The parser to get the arguments from the signature.
     """
-    parser = argparse.ArgumentParser()
+    parser = argparse.ArgumentParser("pyrunit")
+    required_parser = parser.add_argument_group('required arguments')
     fullargs = inspect.getfullargspec(method)
     args_annotations = dict(filter(lambda key: key[0] != 'return', fullargs.annotations.items()))
 
+    for extra_arg in extra_arguments:
+        parser.add_argument(extra_arg, type=str, )
+
     required_args_idxs = len(args_annotations) - len(fullargs.defaults if fullargs.defaults else [])
     for idx, (arg, arg_type) in enumerate(args_annotations.items()):
         is_required = idx < required_args_idxs
-        argument = f"--{arg.replace('_','-')}"
+        assigned_parser = required_parser if is_required else parser
+        argument_flag = f"--{arg.replace('_','-')}"
 
         if issubclass(arg_type, SimpleNamespace):
             if not is_required:
                 raise ValueError("An argument of type SimpleNamespace can't be optional.\
                      Remove default values.")
-            parser.add_argument(argument,
+            assigned_parser.add_argument(argument_flag,
                                 dest=arg,
-                                type=yml2config,
-                                required=is_required)
+                                type=file2namespace,
+                                required=is_required,
+                                help='indicated as a YAML or JSON file')
         elif issubclass(arg_type, Enum):
-            parser.add_argument(argument,
+            assigned_parser.add_argument(argument_flag,
                                 dest=arg,
                                 type=arg_type,
                                 choices=list(arg_type),
                                 required=is_required)
         else:
-            parser.add_argument(argument,
+            assigned_parser.add_argument(argument_flag,
                                 dest=arg,
                                 type=arg_type,
-                                required=is_required)
+                                required=is_required,
+                                help=f"of type {arg_type.__name__}")
 
-    return parser.parse_args()
+    return parser
+
+def get_args_from_signature(method: Callable, extra_arguments: List[str] = []) -> Dict[str, Any]:
+    """
+    Automatically parses all the arguments to match an specific method. The method should
+    implement type hinting in order for this to work. All arguments required by the method
+    will be also required by the parser. To match bash conventions, arguments with underscore
+    will be parsed as arguments with upperscore. For instance `from_path` will be requested
+    as `--from-path`. Signature arguments with type `SimpleNamespace` have to be specified
+    using a `YAML` file.
+
+    Parameters
+    ----------
+    method: Callable
+        The method the arguments should be extracted from.
+
+    Returns
+    -------
+    Dict[str, Any]
+        The arguments parsed. You can call `method` with `**...` then.
+    """
+    parser = get_parser_from_signature(method, extra_arguments)
+
+    arguments_dict = vars(parser.parse_args())
+    for extra_arg in extra_arguments:
+        arguments_dict.pop(extra_arg)
+
+    return arguments_dict
 
 class TaskArguments():
     """
@@ -156,7 +190,7 @@ class TaskArguments():
             if arg_type is type(self.args[arg_name]):
                 parsed_args[arg_name] = self.args[arg_name]
             elif arg_type is SimpleNamespace and isinstance(self.args[arg_name], str):
-                parsed_args[arg_name] = yml2config(self.args[arg_name])
+                parsed_args[arg_name] = file2namespace(self.args[arg_name])
             else:
                 raise ValueError(f"Parameter {arg_name} is expecting {arg_type} but got \
                     {type(self.args[arg_name])} which is incompatible.")
